"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var types = _interopRequireWildcard(require("@babel/types"));

var _utils = _interopRequireDefault(require("./utils"));

var _constants = _interopRequireDefault(require("./constants"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// services
// constants

/**
 * Visitors service
 *
 * @mixin
 */
const service = {};
/**
 * Program visitor. Will import logger service if we have source or it isn't already imported.
 *
 * @param {Object} path - node path
 * @param {Object} state - node state
 *
 * @return {undefined}
 */

service.program = (path, state) => {
  const validPathAndState = _utils.default.isValidPathAndState(path, state);

  if (validPathAndState) {
    const loggerName = _utils.default.getLoggerName(state);

    const isDefaultLoggerName = loggerName === _constants.default.LOGGER_API;
    const loggerWasImported = Boolean(path.scope.bindings[loggerName]);

    if (!isDefaultLoggerName && !loggerWasImported) {
      // if we have custom logger AND logger was not imported
      //  => add import declaration
      path.unshiftContainer('body', types.importDeclaration([types.importDefaultSpecifier(types.identifier(loggerName))], types.stringLiteral(_utils.default.getLoggerSource(state))));
    }
  }
};
/**
 * Visitor that will insert expression statement (will add logger calls based on path)
 * Logger is added only if:
 *  - the function was not generated by another plugin
 *  - the file matches the pattern for the source
 *  - the file does not match the pattern for the source exclusion
 *
 * @param {Object} path - node path
 * @param {Object} state - node state
 *
 * @return {undefined}
 */


service.insertExpressionStatement = (path, state) => {
  const validPathAndState = _utils.default.isValidPathAndState(path, state);

  if (validPathAndState) {
    _utils.default.addLogger(path, state);
  }
};

var _default = service;
exports.default = _default;